@@ -6,10 +6,10 @@
 	This is a header file for gd font, generated using
 	bdftogd version 0.60 by Jan Pazdziora, adelton@fi.muni.cz
 	from bdf font
-	-FreeType-Lucida Console-Medium-R-Normal--17-160-75-75-C-78-KOI8-U
-	at Fri May 18 13:10:26 2001.
+	-Gemini-Fixed-Medium-R-Normal--15-140-75-75-C-90-KOI8-U
+	at Tue Jan 29 07:24:09 2002.
 	The original bdf was holding following copyright:
-	"Copyright  1993 Bigelow & Holmes Inc. All rights reserved."
+	"Copyright (C) 1994 Cronyx Ltd."
  */
 
 
