@@ -6,10 +6,10 @@
 	This is a header file for gd font, generated using
 	bdftogd version 0.60 by Jan Pazdziora, adelton@fi.muni.cz
 	from bdf font
-	-FreeType-Lucida Console-Medium-R-Normal--12-120-75-75-C-64-KOI8-U
-	at Fri May 18 13:10:25 2001.
+	-Gemini-Fixed-Bold-R-Normal--16-120-100-100-C-80-KOI8-U
+	at Tue Jan 29 07:24:09 2002.
 	The original bdf was holding following copyright:
-	"Copyright  1993 Bigelow & Holmes Inc. All rights reserved."
+	"Copyright (C) 1994 Aleksei Rudnev <alex@kiae.su>"
  */
 
 
